NonStatefulFunctions
====================

Functions that do *not* depend on a previous value.

**Subtypes**:

.. toctree::
   :maxdepth: 1


   DistributionFunctions
   LearningFunctions
   ObjectiveFunctions
   OptimizationFunctions
   SelectionFunctions
   TransferFunctions
   TimerFunctions
   TransformFunctions